SupremeCourt

Orders-(2014-2015)

- About the Supreme Court
- Attorney Search
- Commission on Judicial Tenure and Discipline
- Contact Information
- Disciplinary Board
- Domestic Violence Training and Monitoring Unit
- Ethics Advisory Panel
- Forms
- Frequently Asked Questions
- Mandatory Continuing Legal Education
- Supreme Court Rides the Circuit

# Supreme Court

#### Published Orders 2014 - 2015 Term

Title | Name
--- | ---
In Re: Carl J.S. Lovett and Samuel Lovett, No. 15-122 (June 19, 2015) | 15-122
In the Matter of Ross A. Annenberg, No. 15-172 (June 11, 2015) | 15-172
Seth Parenteau et al. v. Women & Infants’ Hospital., No. 13-193 (June 10, 2015) | 13-193
Jose DeJesus v. State of Rhode Island, No. 14-30 (June 5, 2015) | 14-30
State v. Muhammad Farooq, No. 14-111 (May 27, 2015) | 14-111
In the Matter of Elisa M. Pollard, No. 13-300 (April 21, 2015) | 13-300
Shayna DeCesare v. George W. Delfarno, Nos. 14-36, 14-37 (April 9, 2015) | 14-36, 14-37
In the Matter of Gordon D. Fox, No. 15-99 (April 2, 2015) | 15-99
Twyla Cartwright v. Sandra Powell, in her capacity as Director of Rhode Island Department of Human Services, No. 14-167 | 14-167
In re Pension Cases, Nos. 15-60,62,63,64,65,66,69,70,71 (March 5, 2015) | 15-60,62,63,64,65,66,69,70,71
In the Matter of Janet A. Mastronardi, No. 13-71 (February 24, 2015) | 13-71
In the Matter of Nicholas Gelfuso, No. 15-36 (February 24, 2015) | 15-36
In the Matter of Thomas J. Howard, Jr., No. 15-24 (February 24, 2015) | 15-24
In the Matter of Steven A. Murray, No. 14-316 (February 24, 2015) | 14-316
Mark Watson v. Arriona Quick, No. 14-153 (January 14, 2015) | 14-153
James Lawrence v. State of Rhode Island, No. 15-3 (January 13, 2015) | 15-3
Sona Stevens, Individually and as Executrix of the Estate of Vartan Baligian v. Carel Bainum, No. 14-339 (January 12, 2015) | 14-339
MMB Realty LLC v. Striker’s Bar and Grill, Inc., et al., No. 14-59 (December 8, 2014) | 14-59
In the Matter of William F. Holt, No. 14-308 (November 24, 2014) | 14-308
In the Matter of Robert F. McNelis, No. 14-320 (November 21, 2014) | 14-320
In the Matter of Augustus Charos, Jr., No. 14-321 (November 21, 2014) | 14-321
In the Matter of George E. Babcock, No. 14-319 (November 19, 2014) | 14-319
City National Bank et al. v. Main and West, LLC, et al., No. 14-22 (November 5, 2014) | 14-22
State v. Michael Rocchio, No. 12-192 (October 17, 2014) | 12-192
In the Matter of Leonard L. Bergersen, No. 14-238 (October 14, 2014) | 14-238
In the Matter of Gerard H. Donley, No. 14-237 (October 14, 2014) | 14-237
Lawrence R. O’Leary, Jr. v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-209 (September 25, 2014) | 13-209
Eileen Vieira v. GE Money Bank, WMC Mortgage Corporation, Mortgage Electronic Registration Systems and Arch Bay Holdings, LLC, No. 14-42 (September 25, 2014) | 14-42
Maria J. Casimiro et al. v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-210 (September 25, 2014) | 13-210
Donovan C. Woodruff et al. v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-207 (September 25, 2014) | 13-207
Keith T. Dennis et al. v. Quicken Loans, Inc., et al., No. 13-268 (September 25, 2014) | 13-268
Bethany Moura v. OneWest Bank, FSB, No. 13-178 (September 25, 2014) | 13-219
Lisa M. Bartone v. Mortgage Electronic Registration Systems, Inc., et al, No. 13-178 (September 25, 2014) | 13-178
Jonathan Mensing et al. v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-177 (September 25, 2014) | 13-177
Joseph Botelho v. Joan Botelho, No. 13-271 (September 24, 2014) | 13-271

Compliance Details
javascript:commonShowModalDialog('{SiteUrl}'+ '/_layouts/15/itemexpiration.aspx' +'?ID={ItemId}&List={ListId}', 'center:1;dialogHeight:500px;dialogWidth:500px;resizable:yes;status:no;location:no;menubar:no;help:no', function GotoPageAfterClose(pageid){if(pageid == 'hold') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/hold.aspx' +'?ID={ItemId}&List={ListId}'); return false;} if(pageid == 'audit') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/Reporting.aspx' +'?Category=Auditing&backtype=item&ID={ItemId}&List={ListId}'); return false;} if(pageid == 'config') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/expirationconfig.aspx' +'?ID={ItemId}&List={ListId}'); return false;}}, null);
0x0
0x1
ContentType
0x01
898
Document Set Version History
/_layouts/15/images/versions.gif?rev=23
javascript:SP.UI.ModalDialog.ShowPopupDialog('{SiteUrl}'+ '/_layouts/15/DocSetVersions.aspx' + '?List={ListId}&ID={ItemId}')
0x0
0x0
ContentType
0x0120D520
330
Send To other location
/_layouts/15/images/sendOtherLoc.gif?rev=23
javascript:GoToPage('{SiteUrl}' + '/_layouts/15/docsetsend.aspx' + '?List={ListId}&ID={ItemId}')
0x0
0x0
ContentType
0x0120D520
350